@@ -1,10 +1,12 @@
 # This will only exist in responses >= 0.17
 from collections import defaultdict
 from typing import Any, Dict, List, Optional, Tuple
+from urllib.parse import urlunparse
 
 import responses
 
 from .custom_responses_mock import CallbackResponse, not_implemented_callback
+from .utils import get_equivalent_url_in_aws_domain
 
 
 class CustomRegistry(responses.registries.FirstMatchRegistry):
@@ -27,8 +29,7 @@ class CustomRegistry(responses.registries.FirstMatchRegistry):
         return res
 
     def add(self, response: responses.BaseResponse) -> responses.BaseResponse:
-        if response not in self._registered[response.method]:
-            self._registered[response.method].append(response)
+        self._registered[response.method].append(response)
         return response
 
     def reset(self) -> None:
@@ -42,8 +43,20 @@ class CustomRegistry(responses.registries.FirstMatchRegistry):
         )
         found = []
         match_failed_reasons = []
+
+        # Handle non-standard AWS endpoint hostnames from ISO regions or custom S3 endpoints.
+        parsed_url, url_was_modified = get_equivalent_url_in_aws_domain(request.url)
+        if url_was_modified:
+            url_with_standard_aws_domain = urlunparse(parsed_url)
+            request_with_standard_aws_domain = request.copy()
+            request_with_standard_aws_domain.prepare_url(
+                url_with_standard_aws_domain, {}
+            )
+        else:
+            request_with_standard_aws_domain = request
+
         for response in all_possibles:
-            match_result, reason = response.matches(request)
+            match_result, reason = response.matches(request_with_standard_aws_domain)
             if match_result:
                 found.append(response)
             else:
@@ -56,6 +69,15 @@ class CustomRegistry(responses.registries.FirstMatchRegistry):
             if type(m) is not CallbackResponse or m.callback != not_implemented_callback
         ]
         if implemented_matches:
+            # Prioritize responses.CallbackResponse
+            # Usecases:
+            #
+            #  - Callbacks created by APIGateway to intercept URL requests to *.execute-api.amazonaws.com
+            #
+            for match in implemented_matches:
+                if type(match) == responses.CallbackResponse:
+                    return match, match_failed_reasons
+            # Return moto.core.custom_responses_mock.CallbackResponse otherwise
             return implemented_matches[0], match_failed_reasons
         elif found:
             # We had matches, but all were of type not_implemented_callback
