@@ -1,19 +1,22 @@
 import json
+from typing import Any, Dict, Tuple, Union
 
 from moto.core.responses import BaseResponse
 
-from .models import efs_backends
+from .models import EFSBackend, efs_backends
+
+TYPE_RESPONSE = Tuple[str, Dict[str, Union[str, int]]]
 
 
 class EFSResponse(BaseResponse):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__(service_name="efs")
 
     @property
-    def efs_backend(self):
+    def efs_backend(self) -> EFSBackend:
         return efs_backends[self.current_account][self.region]
 
-    def create_file_system(self):
+    def create_file_system(self) -> TYPE_RESPONSE:
         creation_token = self._get_param("CreationToken")
         performance_mode = self._get_param("PerformanceMode")
         encrypted = self._get_param("Encrypted")
@@ -41,7 +44,7 @@ class EFSResponse(BaseResponse):
             {"status": 201, "Content-Type": "application/json"},
         )
 
-    def describe_file_systems(self):
+    def describe_file_systems(self) -> TYPE_RESPONSE:
         max_items = self._get_int_param("MaxItems", 10)
         marker = self._get_param("Marker")
         creation_token = self._get_param("CreationToken")
@@ -52,14 +55,16 @@ class EFSResponse(BaseResponse):
             creation_token=creation_token,
             file_system_id=file_system_id,
         )
-        resp_json = {"FileSystems": [fs.info_json() for fs in file_systems]}
+        resp_json: Dict[str, Any] = {
+            "FileSystems": [fs.info_json() for fs in file_systems]
+        }
         if marker:
             resp_json["Marker"] = marker
         if next_marker:
             resp_json["NextMarker"] = next_marker
         return json.dumps(resp_json), {"Content-Type": "application/json"}
 
-    def create_mount_target(self):
+    def create_mount_target(self) -> TYPE_RESPONSE:
         file_system_id = self._get_param("FileSystemId")
         subnet_id = self._get_param("SubnetId")
         ip_address = self._get_param("IpAddress")
@@ -75,7 +80,7 @@ class EFSResponse(BaseResponse):
             {"Content-Type": "application/json"},
         )
 
-    def describe_mount_targets(self):
+    def describe_mount_targets(self) -> TYPE_RESPONSE:
         max_items = self._get_int_param("MaxItems", 10)
         marker = self._get_param("Marker")
         file_system_id = self._get_param("FileSystemId")
@@ -88,30 +93,32 @@ class EFSResponse(BaseResponse):
             access_point_id=access_point_id,
             marker=marker,
         )
-        resp_json = {"MountTargets": [mt.info_json() for mt in mount_targets]}
+        resp_json: Dict[str, Any] = {
+            "MountTargets": [mt.info_json() for mt in mount_targets]
+        }
         if marker:
             resp_json["Marker"] = marker
         if next_marker:
             resp_json["NextMarker"] = next_marker
         return json.dumps(resp_json), {"Content-Type": "application/json"}
 
-    def delete_file_system(self):
+    def delete_file_system(self) -> TYPE_RESPONSE:
         file_system_id = self._get_param("FileSystemId")
         self.efs_backend.delete_file_system(file_system_id)
         return json.dumps(dict()), {"status": 204, "Content-Type": "application/json"}
 
-    def delete_mount_target(self):
+    def delete_mount_target(self) -> TYPE_RESPONSE:
         mount_target_id = self._get_param("MountTargetId")
         self.efs_backend.delete_mount_target(mount_target_id)
         return json.dumps(dict()), {"status": 204, "Content-Type": "application/json"}
 
-    def describe_backup_policy(self):
+    def describe_backup_policy(self) -> TYPE_RESPONSE:
         file_system_id = self._get_param("FileSystemId")
         backup_policy = self.efs_backend.describe_backup_policy(file_system_id)
         resp = {"BackupPolicy": backup_policy}
         return json.dumps(resp), {"Content-Type": "application/json"}
 
-    def put_lifecycle_configuration(self):
+    def put_lifecycle_configuration(self) -> TYPE_RESPONSE:
         file_system_id = self._get_param("FileSystemId")
         policies = self._get_param("LifecyclePolicies")
         self.efs_backend.put_lifecycle_configuration(file_system_id, policies)
@@ -119,14 +126,14 @@ class EFSResponse(BaseResponse):
             "Content-Type": "application/json"
         }
 
-    def describe_lifecycle_configuration(self):
+    def describe_lifecycle_configuration(self) -> TYPE_RESPONSE:
         file_system_id = self._get_param("FileSystemId")
         policies = self.efs_backend.describe_lifecycle_configuration(file_system_id)
         return json.dumps({"LifecyclePolicies": policies}), {
             "Content-Type": "application/json"
         }
 
-    def describe_mount_target_security_groups(self):
+    def describe_mount_target_security_groups(self) -> TYPE_RESPONSE:
         mount_target_id = self._get_param("MountTargetId")
         security_groups = self.efs_backend.describe_mount_target_security_groups(
             mount_target_id
@@ -135,7 +142,7 @@ class EFSResponse(BaseResponse):
             "Content-Type": "application/json"
         }
 
-    def modify_mount_target_security_groups(self):
+    def modify_mount_target_security_groups(self) -> TYPE_RESPONSE:
         mount_target_id = self._get_param("MountTargetId")
         security_groups = self._get_param("SecurityGroups")
         self.efs_backend.modify_mount_target_security_groups(
@@ -143,7 +150,7 @@ class EFSResponse(BaseResponse):
         )
         return "{}", {"Content-Type": "application/json"}
 
-    def create_access_point(self):
+    def create_access_point(self) -> TYPE_RESPONSE:
         client_token = self._get_param("ClientToken")
         tags = self._get_param("Tags") or []
         file_system_id = self._get_param("FileSystemId")
@@ -160,30 +167,59 @@ class EFSResponse(BaseResponse):
             "Content-Type": "application/json"
         }
 
-    def describe_access_points(self):
+    def describe_access_points(self) -> TYPE_RESPONSE:
         access_point_id = self._get_param("AccessPointId")
-        access_points = self.efs_backend.describe_access_points(access_point_id)
+        file_system_id = self._get_param("FileSystemId")
+        access_points = self.efs_backend.describe_access_points(
+            access_point_id, file_system_id
+        )
         resp = [ap.info_json() for ap in access_points]
         return json.dumps({"AccessPoints": resp}), {"Content-Type": "application/json"}
 
-    def delete_access_point(self):
+    def delete_access_point(self) -> TYPE_RESPONSE:
         access_point_id = self._get_param("AccessPointId")
         self.efs_backend.delete_access_point(access_point_id)
         return "{}", {"Content-Type": "application/json"}
 
-    def list_tags_for_resource(self):
+    def list_tags_for_resource(self) -> TYPE_RESPONSE:
         resource_id = self._get_param("ResourceId")
         tags = self.efs_backend.list_tags_for_resource(resource_id)
         return json.dumps({"Tags": tags}), {"Content-Type": "application/json"}
 
-    def tag_resource(self):
+    def tag_resource(self) -> TYPE_RESPONSE:
         resource_id = self._get_param("ResourceId")
         tags = self._get_param("Tags")
         self.efs_backend.tag_resource(resource_id, tags)
         return "{}", {"Content-Type": "application/json"}
 
-    def untag_resource(self):
+    def untag_resource(self) -> TYPE_RESPONSE:
         resource_id = self._get_param("ResourceId")
         tag_keys = self.querystring.get("tagKeys", [])
         self.efs_backend.untag_resource(resource_id, tag_keys)
         return "{}", {"Content-Type": "application/json"}
+
+    def describe_file_system_policy(self) -> TYPE_RESPONSE:
+        file_system_id = self._get_param("FileSystemId")
+        policy = self.efs_backend.describe_file_system_policy(
+            file_system_id=file_system_id,
+        )
+        return (
+            json.dumps(dict(FileSystemId=file_system_id, Policy=policy)),
+            {"Content-Type": "application/json"},
+        )
+
+    def put_file_system_policy(self) -> TYPE_RESPONSE:
+        file_system_id = self._get_param("FileSystemId")
+        policy = self._get_param("Policy")
+        bypass_policy_lockout_safety_check = (
+            self._get_param("BypassPolicyLockoutSafetyCheck") or False
+        )
+        self.efs_backend.put_file_system_policy(
+            file_system_id=file_system_id,
+            policy=policy,
+            bypass_policy_lockout_safety_check=bypass_policy_lockout_safety_check,
+        )
+        return (
+            json.dumps(dict(FileSystemId=file_system_id, Policy=policy)),
+            {"Content-Type": "application/json"},
+        )
