@@ -1,4 +1,5 @@
 """Handles incoming identitystore requests, invokes methods, returns responses."""
+
 import json
 from typing import Any, Dict, NamedTuple, Optional
 
@@ -137,12 +138,34 @@ class IdentityStoreResponse(BaseResponse):
             dict(GroupMemberships=group_memberships, NextToken=next_token)
         )
 
+    def list_group_memberships_for_member(self) -> str:
+        identity_store_id = self._get_param("IdentityStoreId")
+        member_id = self._get_param("MemberId")
+        max_results = self._get_param("MaxResults")
+        next_token = self._get_param("NextToken")
+        (
+            group_memberships,
+            next_token,
+        ) = self.identitystore_backend.list_group_memberships_for_member(
+            identity_store_id=identity_store_id,
+            member_id=member_id,
+            max_results=max_results,
+            next_token=next_token,
+        )
+
+        return json.dumps(
+            dict(GroupMemberships=group_memberships, NextToken=next_token)
+        )
+
     def list_groups(self) -> str:
         identity_store_id = self._get_param("IdentityStoreId")
         max_results = self._get_param("MaxResults")
         next_token = self._get_param("NextToken")
         filters = self._get_param("Filters")
-        (groups, next_token,) = self.identitystore_backend.list_groups(
+        (
+            groups,
+            next_token,
+        ) = self.identitystore_backend.list_groups(
             identity_store_id=identity_store_id,
             max_results=max_results,
             next_token=next_token,
@@ -179,7 +202,10 @@ class IdentityStoreResponse(BaseResponse):
         max_results = self._get_param("MaxResults")
         next_token = self._get_param("NextToken")
         filters = self._get_param("Filters")
-        (users, next_token,) = self.identitystore_backend.list_users(
+        (
+            users,
+            next_token,
+        ) = self.identitystore_backend.list_users(
             identity_store_id=identity_store_id,
             max_results=max_results,
             next_token=next_token,
