@@ -1,15 +1,16 @@
 import json
 import time
-import jsondiff
-from typing import Any, Dict, List, Tuple, Optional
+from typing import Any, Dict, List, Optional, Tuple
 
-from moto.core import BaseBackend, BackendDict, BaseModel
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel
 from moto.core.utils import merge_dicts
-from moto.iot.models import iot_backends, IoTBackend
+from moto.iot.models import IoTBackend, iot_backends
+
 from .exceptions import (
     ConflictException,
-    ResourceNotFoundException,
     InvalidRequestException,
+    ResourceNotFoundException,
 )
 
 
@@ -41,7 +42,9 @@ class FakeShadow(BaseModel):
         )
 
     @classmethod
-    def create_from_previous_version(cls, previous_shadow: Optional["FakeShadow"], payload: Optional[Dict[str, Any]]) -> "FakeShadow":  # type: ignore[misc]
+    def create_from_previous_version(  # type: ignore[misc]
+        cls, previous_shadow: Optional["FakeShadow"], payload: Optional[Dict[str, Any]]
+    ) -> "FakeShadow":
         """
         set None to payload when you want to delete shadow
         """
@@ -66,15 +69,42 @@ class FakeShadow(BaseModel):
         return FakeShadow(desired, reported, payload, version)
 
     @classmethod
-    def parse_payload(cls, desired: Optional[str], reported: Optional[str]) -> Any:  # type: ignore[misc]
-        if desired is None:
-            delta = reported
-        elif reported is None:
+    def parse_payload(cls, desired: Any, reported: Any) -> Any:  # type: ignore[misc]
+        if not desired and not reported:
+            delta = None
+        elif reported is None and desired:
             delta = desired
+        elif desired and reported:
+            delta = cls._compute_delta_dict(desired, reported)
         else:
-            delta = jsondiff.diff(desired, reported)
+            delta = None
         return delta
 
+    @classmethod
+    def _compute_delta_dict(cls, desired: Any, reported: Any) -> Dict[str, Any]:  # type: ignore[misc]
+        delta = {}
+        for key, value in desired.items():
+            delta_value = cls._compute_delta(reported.get(key), value)
+
+            if delta_value is not None:
+                delta[key] = delta_value
+        return delta
+
+    @classmethod
+    def _compute_delta(cls, reported_value: Any, desired_value: Any) -> Any:  # type: ignore[misc]
+        if reported_value == desired_value:
+            return None
+
+        if isinstance(desired_value, dict) and isinstance(reported_value, dict):
+            return cls._compute_delta_dict(desired_value, reported_value)
+
+        # Types are different, or
+        # Both types are intrinsic values (str, int, etc), or
+        # Both types are lists:
+        #
+        # Just return the desired value
+        return desired_value
+
     def _create_metadata_from_state(self, state: Any, ts: Any) -> Any:
         """
         state must be desired or reported stype dict object
@@ -124,11 +154,11 @@ class FakeShadow(BaseModel):
             return {"timestamp": self.timestamp, "version": self.version}
         delta = self.parse_payload(self.desired, self.reported)
         payload = {}
-        if self.desired is not None:
+        if self.desired:
             payload["desired"] = self.desired
-        if self.reported is not None:
+        if self.reported:
             payload["reported"] = self.reported
-        if include_delta and (delta is not None and len(delta.keys()) != 0):
+        if include_delta and delta:
             payload["delta"] = delta
 
         metadata = {}
@@ -148,13 +178,15 @@ class FakeShadow(BaseModel):
 class IoTDataPlaneBackend(BaseBackend):
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.published_payloads: List[Tuple[str, str]] = list()
+        self.published_payloads: List[Tuple[str, bytes]] = list()
 
     @property
     def iot_backend(self) -> IoTBackend:
         return iot_backends[self.account_id][self.region_name]
 
-    def update_thing_shadow(self, thing_name: str, payload: str) -> FakeShadow:
+    def update_thing_shadow(
+        self, thing_name: str, payload: str, shadow_name: Optional[str]
+    ) -> FakeShadow:
         """
         spec of payload:
           - need node `state`
@@ -175,34 +207,41 @@ class IoTDataPlaneBackend(BaseBackend):
         if any(_ for _ in _payload["state"].keys() if _ not in ["desired", "reported"]):
             raise InvalidRequestException("State contains an invalid node")
 
-        if "version" in _payload and thing.thing_shadow.version != _payload["version"]:
+        thing_shadow = thing.thing_shadows.get(shadow_name)
+        if "version" in _payload and thing_shadow.version != _payload["version"]:  # type: ignore
             raise ConflictException("Version conflict")
-        new_shadow = FakeShadow.create_from_previous_version(
-            thing.thing_shadow, _payload
-        )
-        thing.thing_shadow = new_shadow
-        return thing.thing_shadow
+        new_shadow = FakeShadow.create_from_previous_version(thing_shadow, _payload)
+        thing.thing_shadows[shadow_name] = new_shadow
+        return new_shadow
 
-    def get_thing_shadow(self, thing_name: str) -> FakeShadow:
+    def get_thing_shadow(
+        self, thing_name: str, shadow_name: Optional[str]
+    ) -> FakeShadow:
         thing = self.iot_backend.describe_thing(thing_name)
+        thing_shadow = thing.thing_shadows.get(shadow_name)
 
-        if thing.thing_shadow is None or thing.thing_shadow.deleted:
+        if thing_shadow is None or thing_shadow.deleted:
             raise ResourceNotFoundException()
-        return thing.thing_shadow
+        return thing_shadow
 
-    def delete_thing_shadow(self, thing_name: str) -> FakeShadow:
+    def delete_thing_shadow(
+        self, thing_name: str, shadow_name: Optional[str]
+    ) -> FakeShadow:
         thing = self.iot_backend.describe_thing(thing_name)
-        if thing.thing_shadow is None:
+        thing_shadow = thing.thing_shadows.get(shadow_name)
+        if thing_shadow is None:
             raise ResourceNotFoundException()
         payload = None
-        new_shadow = FakeShadow.create_from_previous_version(
-            thing.thing_shadow, payload
-        )
-        thing.thing_shadow = new_shadow
-        return thing.thing_shadow
+        new_shadow = FakeShadow.create_from_previous_version(thing_shadow, payload)
+        thing.thing_shadows[shadow_name] = new_shadow
+        return new_shadow
 
-    def publish(self, topic: str, payload: str) -> None:
+    def publish(self, topic: str, payload: bytes) -> None:
         self.published_payloads.append((topic, payload))
 
+    def list_named_shadows_for_thing(self, thing_name: str) -> List[str]:
+        thing = self.iot_backend.describe_thing(thing_name)
+        return [name for name in thing.thing_shadows.keys() if name is not None]
 
-iotdata_backends = BackendDict(IoTDataPlaneBackend, "iot")
+
+iotdata_backends = BackendDict(IoTDataPlaneBackend, "iot-data")
