@@ -2,11 +2,11 @@ import base64
 import json
 import os
 import re
-import warnings
 from typing import Any, Dict
 
 from moto.core.responses import BaseResponse
 from moto.kms.utils import RESERVED_ALIASE_TARGET_KEY_IDS, RESERVED_ALIASES
+from moto.utilities.utils import get_partition
 
 from .exceptions import (
     AlreadyExistsException,
@@ -44,7 +44,7 @@ class KmsResponse(BaseResponse):
         else:
             id_type = "key/"
 
-        return f"arn:aws:kms:{self.region}:{self.current_account}:{id_type}{key_id}"
+        return f"arn:{get_partition(self.region)}:kms:{self.region}:{self.current_account}:{id_type}{key_id}"
 
     def _validate_cmk_id(self, key_id: str) -> None:
         """Determine whether a CMK ID exists.
@@ -246,7 +246,10 @@ class KmsResponse(BaseResponse):
             )
 
         self._validate_cmk_id(target_key_id)
-        self.kms_backend.add_alias(target_key_id, alias_name)
+        if update:
+            self.kms_backend.update_alias(target_key_id, alias_name)
+        else:
+            self.kms_backend.create_alias(target_key_id, alias_name)
 
         return json.dumps(None)
 
@@ -273,13 +276,13 @@ class KmsResponse(BaseResponse):
 
         response_aliases = []
 
-        backend_aliases = self.kms_backend.get_all_aliases()
+        backend_aliases = self.kms_backend.list_aliases()
         for target_key_id, aliases in backend_aliases.items():
             for alias_name in aliases:
                 # TODO: add creation date and last updated in response_aliases
                 response_aliases.append(
                     {
-                        "AliasArn": f"arn:aws:kms:{region}:{self.current_account}:{alias_name}",
+                        "AliasArn": f"arn:{get_partition(region)}:kms:{region}:{self.current_account}:{alias_name}",
                         "AliasName": alias_name,
                         "TargetKeyId": target_key_id,
                     }
@@ -289,7 +292,7 @@ class KmsResponse(BaseResponse):
                 a for a in response_aliases if a["AliasName"] == reserved_alias
             ]
             if not exsisting:
-                arn = f"arn:aws:kms:{region}:{self.current_account}:{reserved_alias}"
+                arn = f"arn:{get_partition(region)}:kms:{region}:{self.current_account}:{reserved_alias}"
                 response_aliases.append(
                     {
                         "TargetKeyId": target_key_id,
@@ -621,20 +624,13 @@ class KmsResponse(BaseResponse):
         return json.dumps({"Plaintext": response_entropy})
 
     def sign(self) -> str:
-        """https://docs.aws.amazon.com/kms/latest/APIReference/API_Sign.html"""
         key_id = self._get_param("KeyId")
         message = self._get_param("Message")
         message_type = self._get_param("MessageType")
-        grant_tokens = self._get_param("GrantTokens")
         signing_algorithm = self._get_param("SigningAlgorithm")
 
         self._validate_key_id(key_id)
 
-        if grant_tokens:
-            warnings.warn(
-                "The GrantTokens-parameter is not yet implemented for client.sign()"
-            )
-
         if isinstance(message, str):
             message = message.encode("utf-8")
 
@@ -669,20 +665,9 @@ class KmsResponse(BaseResponse):
         message_type = self._get_param("MessageType")
         signature = self._get_param("Signature")
         signing_algorithm = self._get_param("SigningAlgorithm")
-        grant_tokens = self._get_param("GrantTokens")
 
         self._validate_key_id(key_id)
 
-        if grant_tokens:
-            warnings.warn(
-                "The GrantTokens-parameter is not yet implemented for client.verify()"
-            )
-
-        if message_type == "DIGEST":
-            warnings.warn(
-                "The MessageType-parameter DIGEST is not yet implemented for client.verify()"
-            )
-
         if not message_type:
             message_type = "RAW"
 
@@ -722,7 +707,6 @@ class KmsResponse(BaseResponse):
         key_id = self._get_param("KeyId")
 
         self._validate_key_id(key_id)
-        self._validate_cmk_id(key_id)
         key, public_key = self.kms_backend.get_public_key(key_id)
         return json.dumps(
             {
